"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const config_1 = require("../helpers/config");
/**
 * Base command that handles the flags used for specifying the desired network.
 */
class NetworkCommand extends command_1.Command {
    getNetworkUrl(flags) {
        const [, url] = this.getNetworkUrlAndKind(flags);
        return url;
    }
    getNetworkUrlAndKind(flags) {
        const networks = config_1.getNetworks();
        const name = flags.mainnet
            ? 'mainnet'
            : flags.ropsten
                ? 'ropsten'
                : flags.rinkeby
                    ? 'rinkeby'
                    : flags.goerli
                        ? 'goerli'
                        : flags.kovan
                            ? 'kovan'
                            : flags.network;
        if (networks[name]) {
            return ['name', networks[name].url, name];
        }
        return ['url', flags.network];
    }
}
exports.NetworkCommand = NetworkCommand;
NetworkCommand.defaultUrl = 'http://localhost:8545';
NetworkCommand.flags = {
    network: command_1.flags.string({
        char: 'n',
        default: NetworkCommand.defaultUrl,
        description: 'URL to connect to, or name of a known network',
    }),
    mainnet: command_1.flags.boolean({ hidden: true }),
    ropsten: command_1.flags.boolean({ hidden: true }),
    rinkeby: command_1.flags.boolean({ hidden: true }),
    goerli: command_1.flags.boolean({ hidden: true }),
    kovan: command_1.flags.boolean({ hidden: true }),
};
