"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const config_1 = require("../../helpers/config");
const utils_1 = require("../../helpers/utils");
class AddCommand extends command_1.Command {
    async run() {
        const { args } = this.parse(AddCommand);
        try {
            const { name, abiPath } = args;
            const abis = config_1.getAbis();
            const { abi } = utils_1.loadABI(abiPath);
            if (abis[name]) {
                this.warn(`ABI '${name}' already exists. Use abi:update if you want to modify it.`);
            }
            else {
                abis[name] = abi;
                config_1.updateAbis(abis);
            }
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.AddCommand = AddCommand;
AddCommand.description = 'Add a known ABI.';
AddCommand.args = [
    {
        name: 'name',
        required: true,
        description: 'Name of the ABI to add',
    },
    {
        name: 'abiPath',
        required: true,
        description: 'Path to the file with the ABI',
    },
];
AddCommand.examples = ['eth abi:add erc777 ./path/to/erc777.json'];
