"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const config_1 = require("../../helpers/config");
const utils_1 = require("../../helpers/utils");
class UpdateCommand extends command_1.Command {
    async run() {
        const { args } = this.parse(UpdateCommand);
        try {
            const { name, abiPath } = args;
            const abis = config_1.getAbis();
            const { abi } = utils_1.loadABI(abiPath);
            if (abis[name]) {
                abis[name] = abi;
                config_1.updateAbis(abis);
            }
            else {
                this.warn(`No ABI found for '${name}'`);
            }
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.UpdateCommand = UpdateCommand;
UpdateCommand.description = 'Update a known ABI.';
UpdateCommand.args = [
    {
        name: 'name',
        required: true,
        description: 'Name of the ABI to add',
    },
    {
        name: 'abiPath',
        required: true,
        description: 'Path to the file with the ABI',
    },
];
UpdateCommand.examples = ['eth abi:update erc777 ./path/to/erc777.json'];
