"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const config_1 = require("../../helpers/config");
const utils_1 = require("../../helpers/utils");
class AddCommand extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(AddCommand);
        try {
            const { name, addressOrPk } = args;
            const { 'network-id': networkId } = flags;
            const addresses = config_1.getAddresses();
            let addressObject = null;
            if (utils_1.isPrivateKey(addressOrPk)) {
                const Accounts = (await Promise.resolve().then(() => tslib_1.__importStar(require('web3-eth-accounts')))).default;
                const accounts = new Accounts();
                const privateKey = utils_1.add0x(addressOrPk);
                const address = accounts.privateKeyToAccount(privateKey).address;
                addressObject = { privateKey, address };
            }
            else if (utils_1.isAddress(addressOrPk)) {
                const address = utils_1.add0x(addressOrPk);
                addressObject = { address };
            }
            else {
                this.warn('You have to specify an address or private key');
                this.exit(1);
                return;
            }
            addresses[name] = addresses[name] || {};
            addresses[name][networkId] = addressObject;
            config_1.updateAddresses(addresses);
            cli_ux_1.default.styledJSON(addressObject);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.AddCommand = AddCommand;
AddCommand.description = 'Add a known address.';
AddCommand.args = [
    {
        name: 'name',
        required: true,
        description: 'Name of the address to add',
    },
    {
        name: 'addressOrPk',
        required: true,
        description: 'Address or private key of the address',
    },
];
AddCommand.flags = {
    'network-id': command_1.flags.string({
        char: 'n',
        required: false,
        default: '*',
    }),
};
AddCommand.examples = [
    'eth address:add ganache 0x4f3edf983ac636a65a842ce7c78d9aa706d3b113bce9c46f30d7d21715b23b1d',
    'eth address:add dai 0x89d24a6b4ccb1b6faa2625fe562bdd9a23260359 -n 1',
];
