"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const network_1 = require("../../base/network");
const convert_1 = require("../../helpers/convert");
const types_1 = require("../../types");
class BalanceCommand extends network_1.NetworkCommand {
    async run() {
        const { args, flags } = this.parse(BalanceCommand);
        const { address } = args;
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { getBalance } = await Promise.resolve().then(() => __importStar(require('../../helpers/getBalance')));
            const balance = await getBalance(address, networkUrl);
            const balanceInEth = convert_1.convert(balance, types_1.Unit.Wei, types_1.Unit.Eth);
            this.log(balanceInEth);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.default = BalanceCommand;
BalanceCommand.description = `Get the balance of the given address.`;
BalanceCommand.args = [
    {
        name: 'address',
        required: true,
        description: 'Address or name of a known address',
    },
];
BalanceCommand.flags = Object.assign({}, network_1.NetworkCommand.flags);
BalanceCommand.examples = ['eth address:balance 0x90F8bf6A479f320ead074411a4B0e7944Ea8c9C1'];
