"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const config_1 = require("../../helpers/config");
class ListCommand extends command_1.Command {
    async run() {
        const { flags } = this.parse(ListCommand);
        const { table, json } = flags;
        const displayAsTable = (!table && !json) || table;
        const addresses = config_1.getAddresses();
        if (displayAsTable) {
            const addressesList = [];
            for (const [name, addressPerNetwork] of Object.entries(addresses)) {
                for (const [networkId, addressObject] of Object.entries(addressPerNetwork)) {
                    addressesList.push(Object.assign({ networkId,
                        name }, addressObject));
                }
            }
            cli_ux_1.default.table(addressesList, {
                networkId: {
                    header: 'Network',
                },
                name: {
                    header: 'Name',
                },
                address: {
                    header: 'Address',
                },
                privateKey: {
                    header: 'Private key',
                    get: row => row.privateKey || '',
                },
            }, Object.assign({ printLine: this.log }, flags));
        }
        else {
            cli_ux_1.default.styledJSON(addresses);
        }
    }
}
exports.ListCommand = ListCommand;
ListCommand.description = 'Display the list of known addresses.';
ListCommand.examples = ['eth address:list'];
ListCommand.flags = {
    json: command_1.flags.boolean({
        description: 'Display data in a json structure.',
        required: false,
        exclusive: ['table'],
    }),
    table: command_1.flags.boolean({
        description: 'Display data in a table structure.',
        required: false,
        exclusive: ['json'],
    }),
};
