"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
class RandomCommand extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(RandomCommand);
        const { amount = '1' } = args;
        const { prefix = '', password: promptForPassword = '' } = flags;
        const amountNumber = parseInt(amount, 10);
        if (promptForPassword && amountNumber > 1) {
            this.error('Only 1 address can be generated when --password is used');
        }
        try {
            const { randomAddress, generateKeystore } = await Promise.resolve().then(() => __importStar(require('../../helpers/randomAddress')));
            if (promptForPassword) {
                const password = await cli_ux_1.cli.prompt('Password', { type: 'hide' });
                const [{ privateKey }] = randomAddress(1, prefix);
                const keystore = await generateKeystore(privateKey, password);
                cli_ux_1.cli.styledJSON(keystore);
            }
            else {
                randomAddress(amountNumber, prefix).forEach(({ address, privateKey }) => cli_ux_1.cli.styledJSON({ address, privateKey }));
            }
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.RandomCommand = RandomCommand;
RandomCommand.description = `Generate a random Ethereum address with its private key.`;
RandomCommand.args = [
    {
        name: 'amount',
        required: false,
        default: '1',
        description: 'Can be specified to generate a list of addresses.',
    },
];
RandomCommand.flags = {
    prefix: command_1.flags.string({
        description: 'Prefix of the generated address. The more characters used, the longer it will take to generate it.',
    }),
    password: command_1.flags.boolean({
        description: 'Ask for a password and generate a keystore with it. Only 1 address can be generated when this flags is used.',
    }),
};
RandomCommand.examples = ['eth address:random', 'eth address:random 3', 'eth address:random --prefix aa'];
