"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
class AddressCommand extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(AddressCommand);
        try {
            const { account } = args;
            const { nonce = '0' } = flags;
            const { getContractAddress } = await Promise.resolve().then(() => __importStar(require('../../helpers/getContractAddress')));
            const contractAddress = getContractAddress(account, nonce);
            this.log(contractAddress);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.default = AddressCommand;
AddressCommand.description = `Get the address for a contract created from the given account.`;
AddressCommand.args = [
    {
        name: 'account',
        required: true,
        description: 'The address that will deploy the contract..',
    },
];
AddressCommand.flags = {
    nonce: command_1.flags.string({
        description: 'The nonce of the address that will deploy the contract.',
    }),
};
AddressCommand.examples = [
    'eth contract:address 0x92970dbD5C0Ee6b439422bFd7cD71e1DDA921A03',
    'eth contract:address 0x92970dbD5C0Ee6b439422bFd7cD71e1DDA921A03 --nonce 5',
];
