"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const network_1 = require("../../base/network");
const utils_1 = require("../../helpers/utils");
class CallCommand extends network_1.NetworkCommand {
    async run() {
        const { args, flags } = this.parse(CallCommand);
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { contract: abiAtAddress, methodCall } = args;
            const { contractCall } = await Promise.resolve().then(() => __importStar(require('../../helpers/contractCall')));
            const { getNetworkId } = await Promise.resolve().then(() => __importStar(require('../../helpers/getNetworkId')));
            const networkId = await getNetworkId(networkUrl);
            const { abi, address } = utils_1.getContract(abiAtAddress, String(networkId));
            const result = await contractCall(abi, methodCall, address, networkUrl);
            this.log(result);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.default = CallCommand;
CallCommand.description = `Call a method in the given contract and print the returned value.`;
CallCommand.flags = Object.assign({}, network_1.NetworkCommand.flags);
CallCommand.args = [
    {
        name: 'contract',
        required: true,
        description: `The contract's ABI and address, in abi@address format.`,
    },
    {
        name: 'methodCall',
        required: true,
        description: `e.g.: 'myMethod(arg1,arg2,["a","b",3,["d","0x123..."]])'`,
    },
];
CallCommand.examples = [
    `eth contract:call --rinkeby erc20@0x5592ec0cfb4dbc12d3ab100b257153436a1f0fea 'totalSupply()'`,
];
