"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const network_1 = require("../../base/network");
const flags_1 = require("../../flags");
const transactions_1 = require("../../helpers/transactions");
const utils_1 = require("../../helpers/utils");
class DeployCommand extends network_1.NetworkCommand {
    async run() {
        const { args, flags } = this.parse(DeployCommand);
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { bin } = args;
            const { pk, 'confirmation-blocks': confirmationBlocks, args: constructorArgumentsStr, abi: abiPath, } = flags;
            if (!pk) {
                this.error('You have to specify a private key using --pk', { exit: 1 });
                return;
            }
            if (constructorArgumentsStr && !abiPath) {
                this.error('The --abi flags has to be specified when using --args', { exit: 1 });
                return;
            }
            let constructorArguments = [];
            if (constructorArgumentsStr) {
                try {
                    constructorArguments = JSON.parse(constructorArgumentsStr);
                    if (!Array.isArray(constructorArguments)) {
                        throw new Error('Given arguments are not an array');
                    }
                }
                catch (e) {
                    this.error(`Constructor arguments must be a valid JSON array: ${e.message}`, { exit: 1 });
                    return;
                }
            }
            let abi = [];
            if (abiPath) {
                const { abi: loadedAbi } = utils_1.loadABI(abiPath);
                abi = loadedAbi;
            }
            const { deploy } = await Promise.resolve().then(() => __importStar(require('../../helpers/deploy')));
            const txHash = await deploy(networkUrl, pk, abi, bin, constructorArguments);
            const receipt = await transactions_1.awaitTransactionMined(networkUrl, txHash, confirmationBlocks);
            cli_ux_1.cli.styledJSON({ address: receipt.contractAddress, receipt });
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.DeployCommand = DeployCommand;
DeployCommand.description = `Deploy contract with the given binary.`;
DeployCommand.flags = Object.assign(Object.assign({}, network_1.NetworkCommand.flags), { pk: flags_1.privateKeyFlag, 'confirmation-blocks': flags_1.confirmationBlocksFlag, args: command_1.flags.string({
        description: "Arguments for the contract's constructor.",
    }), abi: command_1.flags.string({
        description: 'ABI of the contract. Required when using --args.',
    }) });
DeployCommand.args = [
    {
        name: 'bin',
        required: true,
        description: 'The bin file of the contract.',
    },
];
DeployCommand.examples = [
    'eth contract:deploy --ropsten --pk 3daa79a26454a5528a3523f9e6345efdbd636e63f8c24a835204e6ccb5c88f9e ./contracts/proxy.bin',
    'eth contract:deploy --pk knownPK --abi erc20 --args ["MYTKN", 18] ./contracts/erc20.bin',
];
DeployCommand.aliases = ['ct:d', 'ct:deploy'];
