"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const network_1 = require("../../base/network");
const flags_1 = require("../../flags");
const utils_1 = require("../../helpers/utils");
const transactions_1 = require("../../helpers/transactions");
class SendCommand extends network_1.NetworkCommand {
    async run() {
        const { args, flags } = this.parse(SendCommand);
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { contract: abiAtAddress, methodCall } = args;
            const { 'confirmation-blocks': confirmationBlocks, pk, value } = flags;
            const { contractCall } = await Promise.resolve().then(() => __importStar(require('../../helpers/contractCall')));
            const { getNetworkId } = await Promise.resolve().then(() => __importStar(require('../../helpers/getNetworkId')));
            const networkId = await getNetworkId(networkUrl);
            const { abi, address } = utils_1.getContract(abiAtAddress, String(networkId));
            const tx = await contractCall(abi, methodCall, address, networkUrl, pk, { value });
            await transactions_1.awaitTransactionMined(networkUrl, tx, confirmationBlocks);
            cli_ux_1.cli.styledJSON(tx);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.default = SendCommand;
SendCommand.description = `Send a transaction calling a method in the given contract.`;
SendCommand.flags = Object.assign(Object.assign({}, network_1.NetworkCommand.flags), { pk: Object.assign(Object.assign({}, flags_1.privateKeyFlag), { required: true }), 'confirmation-blocks': flags_1.confirmationBlocksFlag, 'value': command_1.flags.integer({
        description: 'Amount of ether to be sent with the transaction',
        default: 0,
    }) });
SendCommand.args = [
    {
        name: 'contract',
        required: true,
        description: `The contract's ABI and address, in abi@address format.`,
    },
    {
        name: 'methodCall',
        required: true,
        description: `e.g.: 'myMethod(arg1,arg2,["a","b",3,["d","0x123..."]])'`,
    },
];
SendCommand.examples = [
    `eth contract:send --rinkeby erc20@0x5592ec0cfb4dbc12d3ab100b257153436a1f0fea 'transfer("0x828DaF877f46fdFB5F1239cd9cB8f0D6E1adfb80", 1000000000)'`,
];
