"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const get_stdin_1 = tslib_1.__importDefault(require("get-stdin"));
const convert_1 = require("../helpers/convert");
const types_1 = require("../types");
class ConvertCommand extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(ConvertCommand);
        let { amount } = args;
        const { from: fromRaw, to: toRaw } = flags;
        if (!amount) {
            amount = await get_stdin_1.default();
        }
        const from = convert_1.stringToUnit(fromRaw);
        const to = convert_1.stringToUnit(toRaw);
        if (!from) {
            this.error('--from has to be a valid unit (eth, wei, gwei)');
            return;
        }
        if (!to) {
            this.error('--to has to be a valid unit (eth, wei, gwei)');
            return;
        }
        try {
            const converted = convert_1.convert(amount.trim(), from, to);
            this.log(converted);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.ConvertCommand = ConvertCommand;
ConvertCommand.description = 'Convert from eth to wei, wei to eth, etc.';
ConvertCommand.args = [
    {
        name: 'amount',
        required: false,
        description: 'The amount to convert. Can also be specified through stdin.',
    },
];
ConvertCommand.flags = {
    from: command_1.flags.string({
        char: 'f',
        default: types_1.Unit.Wei,
    }),
    to: command_1.flags.string({
        char: 't',
        default: types_1.Unit.Eth,
    }),
};
ConvertCommand.examples = [
    'eth convert 1000000000000000000',
    'eth convert -f eth -t wei 1',
    'echo 1000000000000000000 | eth convert',
];
