"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const network_1 = require("../../base/network");
const utils_1 = require("../../helpers/utils");
class GetCommand extends network_1.NetworkCommand {
    async run() {
        const { args, flags } = this.parse(GetCommand);
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { contract: abiAtAddress, event } = args;
            const { from, to, json } = flags;
            const { getEvents, parseEvent, processEvent } = await Promise.resolve().then(() => tslib_1.__importStar(require('../../helpers/getEvents')));
            const { getBlockNumber } = await Promise.resolve().then(() => tslib_1.__importStar(require('../../helpers/getBlockNumber')));
            const blockNumber = await getBlockNumber(networkUrl);
            let fromBlock = from;
            if (fromBlock !== 'latest' && +fromBlock < 0) {
                fromBlock = String(blockNumber + Number(from));
            }
            let toBlock = to;
            if (toBlock !== 'latest' && +toBlock < 0) {
                toBlock = String(blockNumber + Number(to));
            }
            const { getNetworkId } = await Promise.resolve().then(() => tslib_1.__importStar(require('../../helpers/getNetworkId')));
            const networkId = await getNetworkId(networkUrl);
            const { abi, address } = utils_1.getContract(abiAtAddress, String(networkId));
            const { events, eventAbi } = await getEvents(abi, event, address, networkUrl, {
                from: fromBlock,
                to: toBlock,
            });
            if (json) {
                events.forEach(event => {
                    cli_ux_1.default.styledJSON(processEvent(event, eventAbi));
                });
            }
            else {
                events.forEach(event => this.log(parseEvent(event, eventAbi)));
            }
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.default = GetCommand;
GetCommand.description = `Get the events in the given block range.`;
GetCommand.flags = Object.assign(Object.assign({}, network_1.NetworkCommand.flags), { from: command_1.flags.string({
        char: 'f',
        required: false,
        default: '1',
        description: 'Start of the block number. Can be a positive number, a negative number, or "latest" (1 by default). A negative number is interpreted as substracted from the current block number.',
    }), to: command_1.flags.string({
        char: 't',
        required: false,
        default: 'latest',
        description: 'End of the block range. Can be a positive number, a negative number, or "latest" (default). A negative number is interpreted as substracted from the current block number.',
    }), json: command_1.flags.boolean({
        description: 'Print events in JSON format',
    }) });
GetCommand.args = [
    {
        name: 'contract',
        required: true,
        description: `The contract's ABI and address, in abi@address format.`,
    },
    {
        name: 'event',
        required: true,
        description: `e.g.: 'MyEvent'`,
    },
];
GetCommand.examples = [
    'eth event:get --mainnet erc20@0x89d24a6b4ccb1b6faa2625fe562bdd9a23260359 Transfer --from 1',
    'eth event:get --mainnet erc20@0x89d24a6b4ccb1b6faa2625fe562bdd9a23260359 Transfer --from 1 --json',
];
