"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const cli_ux_1 = tslib_1.__importDefault(require("cli-ux"));
const network_1 = require("../../base/network");
const utils_1 = require("../../helpers/utils");
class GetCommand extends network_1.NetworkCommand {
    async run() {
        const { args, flags } = this.parse(GetCommand);
        const { json } = flags;
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { contract: abiAtAddress, event } = args;
            const { getEvents, parseEvent, processEvent } = await Promise.resolve().then(() => tslib_1.__importStar(require('../../helpers/getEvents')));
            const { getBlockNumber } = await Promise.resolve().then(() => tslib_1.__importStar(require('../../helpers/getBlockNumber')));
            let fromBlock = await getBlockNumber(networkUrl);
            const { getNetworkId } = await Promise.resolve().then(() => tslib_1.__importStar(require('../../helpers/getNetworkId')));
            const networkId = await getNetworkId(networkUrl);
            const { abi, address } = utils_1.getContract(abiAtAddress, String(networkId));
            while (true) {
                const toBlock = await getBlockNumber(networkUrl);
                if (fromBlock <= toBlock) {
                    const { events, eventAbi } = await getEvents(abi, event, address, networkUrl, {
                        from: fromBlock,
                        to: toBlock,
                    });
                    if (json) {
                        events.forEach(event => cli_ux_1.default.styledJSON(processEvent(event, eventAbi)));
                    }
                    else {
                        events.forEach(event => this.log(parseEvent(event, eventAbi)));
                    }
                    fromBlock = toBlock + 1;
                }
                await new Promise((res) => setTimeout(res, 5000));
            }
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.default = GetCommand;
GetCommand.description = `Emit new events from the given type in the given contract.`;
GetCommand.flags = Object.assign(Object.assign({}, network_1.NetworkCommand.flags), { json: command_1.flags.boolean({
        description: 'Print events in JSON format',
    }) });
GetCommand.args = [
    {
        name: 'contract',
        required: true,
        description: `The contract's ABI and address, in abi@address format.`,
    },
    {
        name: 'event',
        required: true,
        description: `e.g.: 'MyEvent'`,
    },
];
GetCommand.examples = [
    'eth event:get --mainnet erc20@0x89d24a6b4ccb1b6faa2625fe562bdd9a23260359 Transfer',
    'eth event:get --mainnet erc20@0x89d24a6b4ccb1b6faa2625fe562bdd9a23260359 Transfer --json',
];
