"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const config_1 = require("../../helpers/config");
class AddCommand extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(AddCommand);
        try {
            const { name } = args;
            const { id, label, url } = flags;
            const newNetwork = { url };
            if (id) {
                newNetwork.id = +id;
            }
            if (label) {
                newNetwork.label = label;
            }
            const networks = config_1.getNetworks();
            if (networks[name]) {
                this.warn(`Network '${name}' already exists. Use network:update if you want to modify it.`);
            }
            else {
                networks[name] = newNetwork;
                config_1.updateNetworks(networks);
            }
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.AddCommand = AddCommand;
AddCommand.description = 'Add a known network.';
AddCommand.args = [
    {
        name: 'name',
        required: true,
        description: 'Name of the network to add',
    },
];
AddCommand.flags = {
    url: command_1.flags.string({
        required: true,
    }),
    id: command_1.flags.string({
        required: false,
    }),
    label: command_1.flags.string({
        required: false,
    }),
};
AddCommand.examples = ['eth network:add rsk --url https://public-node.rsk.co --id 30 --label RSK'];
