"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const config_1 = require("../../helpers/config");
class ListCommand extends command_1.Command {
    async run() {
        try {
            const { flags } = this.parse(ListCommand);
            const { table, json } = flags;
            // display as table by default
            const displayAsTable = (!table && !json) || table;
            if (displayAsTable) {
                const networkConstants = Object.entries(config_1.getNetworks()).map(([name, network]) => (Object.assign({ name }, network)));
                const networks = networkConstants
                    .sort((network1, network2) => {
                    if (network1.id !== undefined && network2.id !== undefined) {
                        return network1.id - network2.id;
                    }
                    else if (network1.id !== undefined) {
                        return -1;
                    }
                    else {
                        return 1;
                    }
                })
                    .map(network => (Object.assign(Object.assign({}, network), { id: network.id || '', label: network.label || '' })));
                cli_ux_1.cli.table(networks, {
                    id: {
                        header: 'Id',
                        minWidth: 7,
                    },
                    name: {
                        header: 'Name',
                    },
                    label: {
                        header: 'Label',
                    },
                    url: {
                        header: 'Url',
                    },
                }, Object.assign({ printLine: this.log }, flags));
            }
            else {
                cli_ux_1.cli.styledJSON(config_1.getNetworks());
            }
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.default = ListCommand;
ListCommand.description = `Show information for each known network.`;
ListCommand.aliases = ['networks'];
ListCommand.flags = {
    json: command_1.flags.boolean({
        description: 'Display data in a json structure.',
        required: false,
        exclusive: ['table'],
    }),
    table: command_1.flags.boolean({
        description: 'Display data in a table structure.',
        required: false,
        exclusive: ['json'],
    }),
};
ListCommand.examples = ['eth network:list --display json', 'eth networks'];
