"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const config_1 = require("../../helpers/config");
class UpdateCommand extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(UpdateCommand);
        try {
            const { name } = args;
            const { id, label, url } = flags;
            const networks = config_1.getNetworks();
            if (networks[name]) {
                const network = networks[name];
                if (url) {
                    network.url = url;
                }
                if (id) {
                    network.id = +id;
                }
                if (label) {
                    network.label = label;
                }
                networks[name] = network;
                config_1.updateNetworks(networks);
            }
            else {
                this.warn(`No network found for '${name}'`);
            }
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.UpdateCommand = UpdateCommand;
UpdateCommand.description = 'Update a known network.';
UpdateCommand.args = [
    {
        name: 'name',
        required: true,
        description: 'Name of the network to update',
    },
];
UpdateCommand.flags = {
    url: command_1.flags.string({
        required: false,
    }),
    id: command_1.flags.string({
        required: false,
    }),
    label: command_1.flags.string({
        required: false,
    }),
};
UpdateCommand.examples = ['eth network:update rsk --id 30'];
