"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const network_1 = require("../base/network");
const flags_1 = require("../flags");
const parseReplContracts = (args) => {
    const result = args.map(arg => {
        const [abiPath, address] = arg.split('@');
        if (!abiPath || !address) {
            throw new Error(`Invalid argument '${arg}', expected <abi>@<contractAddress>`);
        }
        return { abiPath, address };
    });
    return result;
};
class ReplCommand extends network_1.NetworkCommand {
    async run() {
        const { flags, argv } = this.parse(ReplCommand);
        try {
            const [networkKind, networkUrl, networkName] = this.getNetworkUrlAndKind(flags);
            const prompt = networkKind === 'url'
                ? networkUrl === network_1.NetworkCommand.defaultUrl
                    ? '> '
                    : `${networkUrl}> `
                : `${networkName || flags.network}> `;
            const contracts = parseReplContracts(argv);
            const privateKey = flags.pk;
            const { startRepl } = await Promise.resolve().then(() => __importStar(require('../helpers/startRepl')));
            await startRepl(networkUrl, prompt, contracts, privateKey);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.default = ReplCommand;
ReplCommand.description = `Start a REPL that connects to an RPC node ('localhost:8545' by default).

The started REPL exposes a \`web3\` object that you can use to interact with the
node. There's also an \`eth\` object to save you from typing \`web3.eth\`.

You can also indicate some contracts to load in the REPL; see the examples to
learn how to do this.`;
ReplCommand.strict = false;
ReplCommand.flags = Object.assign(Object.assign({}, network_1.NetworkCommand.flags), { pk: flags_1.privateKeyFlag });
ReplCommand.args = [
    {
        name: 'contracts...',
        description: './path/to/contractABI@address',
    },
];
ReplCommand.examples = [
    'eth repl',
    'eth repl --mainnet',
    'eth repl --url=http://localhost:7545',
    'eth repl ./abis/myContract.json@0xaD2FA57bd95A3dfF0e1728686997F6f2fE67F6f9',
    'eth repl erc20@0x34ee482D419229dAad23f27C44B82075B9418D31 erc721@0xcba140186Fa0436e5155fF6DC909F22Ec4648b12',
];
