"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const cli_ux_1 = require("cli-ux");
const network_1 = require("../../base/network");
class GetCommand extends network_1.NetworkCommand {
    async run() {
        const { args, flags } = this.parse(GetCommand);
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { txHash } = args;
            const { getTransaction, getReceipt } = await Promise.resolve().then(() => __importStar(require('../../helpers/getTransactionObject')));
            const promises = [
                getTransaction(txHash, networkUrl),
                getReceipt(txHash, networkUrl),
            ];
            const [transaction, receipt] = await Promise.all(promises);
            let output;
            if (transaction) {
                output = Object.assign(Object.assign({}, transaction), { receipt });
            }
            else {
                output = null;
            }
            cli_ux_1.cli.styledJSON(output);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.default = GetCommand;
GetCommand.description = `Print the transaction object for the given transaction hash.`;
GetCommand.flags = Object.assign({}, network_1.NetworkCommand.flags);
GetCommand.args = [
    {
        name: 'txHash',
        required: true,
        description: 'The transaction hash.',
    },
];
GetCommand.examples = [
    'eth transaction:get --mainnet 0xc83836f1b3acac94a31de8e24c913aceaa9ebc51c93cd374429590596091584a',
    'eth transaction:get --ropsten 0xc83836f1b3acac94a31de8e24c913aceaa9ebc51c93cd374429590596091584a',
    'eth transaction:get --url= http://localhost:8545 0xc83836f1b3acac94a31de8e24c913aceaa9ebc51c93cd374429590596091584a',
];
GetCommand.aliases = ['tx:get'];
