"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const cli_ux_1 = require("cli-ux");
const network_1 = require("../../base/network");
const flags_1 = require("../../flags");
const transactions_1 = require("../../helpers/transactions");
class NopCommand extends network_1.NetworkCommand {
    async run() {
        const { flags } = this.parse(NopCommand);
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { 'confirmation-blocks': confirmationBlocks, pk } = flags;
            if (!pk) {
                this.error('Please specify a private key using --pk', { exit: 1 });
                return;
            }
            const { generateNop } = await Promise.resolve().then(() => __importStar(require('../../helpers/generateNop')));
            const tx = await generateNop(networkUrl, pk);
            await transactions_1.awaitTransactionMined(networkUrl, tx, confirmationBlocks);
            cli_ux_1.cli.styledJSON(tx);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.default = NopCommand;
NopCommand.description = `Generates a transaction that does nothing with the given private key.`;
NopCommand.flags = Object.assign(Object.assign({}, network_1.NetworkCommand.flags), { pk: Object.assign(Object.assign({}, flags_1.privateKeyFlag), { required: true }), 'confirmation-blocks': flags_1.confirmationBlocksFlag });
NopCommand.examples = [
    'eth transaction:nop --pk 3daa79a26454a5528a3523f9e6345efdbd636e63f8c24a835204e6ccb5c88f9e',
    'ETH_CLI_PRIVATE_KEY=3daa79a26454a5528a3523f9e6345efdbd636e63f8c24a835204e6ccb5c88f9e eth transaction:nop',
];
NopCommand.aliases = ['tx:nop'];
