"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const network_1 = require("../../base/network");
const flags_1 = require("../../flags");
const transactions_1 = require("../../helpers/transactions");
class SendCommand extends network_1.NetworkCommand {
    async run() {
        const { flags } = this.parse(SendCommand);
        let networkUrl;
        try {
            networkUrl = this.getNetworkUrl(flags);
            const { 'confirmation-blocks': confirmationBlocks, pk, to, gas, gasPrice = '1000000000', value = '0', data = '', } = flags;
            if (!pk) {
                throw new Error('Specify the private key using --pk');
            }
            const { sendRawTransaction } = await Promise.resolve().then(() => __importStar(require('../../helpers/sendRawTransaction')));
            const tx = await sendRawTransaction(networkUrl, pk, to, {
                gas,
                gasPrice,
                value,
                data,
            });
            await transactions_1.awaitTransactionMined(networkUrl, tx, confirmationBlocks);
            cli_ux_1.cli.styledJSON(tx);
        }
        catch (e) {
            this.error(e.message, { exit: 1 });
        }
    }
}
exports.default = SendCommand;
SendCommand.description = `Send a raw transaction`;
SendCommand.flags = Object.assign(Object.assign({}, network_1.NetworkCommand.flags), { pk: Object.assign(Object.assign({}, flags_1.privateKeyFlag), { required: true }), 'confirmation-blocks': flags_1.confirmationBlocksFlag, to: command_1.flags.string({
        description: 'The recipient address of the transaction',
        required: true,
    }), gas: command_1.flags.string({
        description: 'The gas limit of the transaction. Will be estimated if not specified.',
    }), gasPrice: command_1.flags.string({
        description: 'The gas price of the transaction, in wei. Defaults to 1 gwei.',
    }), value: command_1.flags.string({
        description: 'The amount of eth to send with the transaciton, in wei.',
    }), data: command_1.flags.string({
        description: 'The raw data field of the transaction. Consider using contract:send instead of this.',
    }) });
SendCommand.examples = [
    'eth transaction:send --pk 3daa79a26454a5528a3523f9e6345efdbd636e63f8c24a835204e6ccb5c88f9e --to 0x828DaF877f46fdFB5F1239cd9cB8f0D6E1adfb80 --value 1000000000000000000',
];
SendCommand.aliases = ['tx:send'];
