"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const conf_1 = tslib_1.__importDefault(require("conf"));
const utils_1 = require("./utils");
const config = new conf_1.default({ projectName: 'eth-cli' });
exports.getPrivateKey = (privateKeyOrKnownAddress, networkId) => {
    const addresses = config.get('addresses', {});
    // if it's a known address, use its private key; throw error if it doesn't have one
    // otherwise, interpret the parameter as a private key
    let privateKey;
    if (addresses[privateKeyOrKnownAddress] && addresses[privateKeyOrKnownAddress][networkId]) {
        if (addresses[privateKeyOrKnownAddress][networkId].privateKey) {
            privateKey = addresses[privateKeyOrKnownAddress][networkId].privateKey;
        }
        else {
            throw new Error("Selected address doesn't have a known private key");
        }
    }
    else {
        privateKey = privateKeyOrKnownAddress;
    }
    return utils_1.add0x(privateKey);
};
exports.getAbis = () => {
    return config.get('abis', {});
};
exports.updateAbis = (abis) => {
    config.set('abis', abis);
};
exports.getAddresses = () => {
    return config.get('addresses', {});
};
exports.updateAddresses = (addresses) => {
    config.set('addresses', addresses);
};
exports.getAddress = (name, networkId) => {
    const addresses = exports.getAddresses();
    if (addresses[name]) {
        if (networkId && addresses[name][networkId]) {
            return utils_1.add0x(addresses[name][networkId].address);
        }
        else if (addresses[name]['*']) {
            return utils_1.add0x(addresses[name]['*'].address);
        }
        else {
            throw new Error(`No known address named ${name}`);
        }
    }
    else {
        return utils_1.add0x(name);
    }
};
const defaultNetworks = {
    mainnet: {
        url: 'https://mainnet.infura.io/v3/76fb6c10f1584483a45a0a28e91b07ad',
        id: 1,
        label: 'Mainnet',
    },
    ropsten: {
        url: 'https://ropsten.infura.io/v3/76fb6c10f1584483a45a0a28e91b07ad',
        id: 3,
        label: 'Ropsten',
    },
    rinkeby: {
        url: 'https://rinkeby.infura.io/v3/76fb6c10f1584483a45a0a28e91b07ad',
        id: 4,
        label: 'Rinkeby',
    },
    goerli: {
        url: 'https://goerli.infura.io/v3/76fb6c10f1584483a45a0a28e91b07ad',
        id: 5,
        label: 'Görli',
    },
    kovan: {
        url: 'https://kovan.infura.io/v3/76fb6c10f1584483a45a0a28e91b07ad',
        id: 42,
        label: 'Kovan',
    },
};
exports.getNetworks = () => {
    const addedNetworks = config.get('networks', {});
    return Object.assign(Object.assign({}, defaultNetworks), addedNetworks);
};
exports.updateNetworks = (networks) => {
    config.set('networks', networks);
};
