"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const web3_1 = tslib_1.__importDefault(require("web3"));
const config_1 = require("./config");
const utils_1 = require("./utils");
async function contractCall(abi, methodCall, name, url, privateKeyOrKnownAddress, extraParams) {
    const { methodValid, methodName } = utils_1.evaluateMethodCallStructure(methodCall);
    if (!methodValid) {
        throw new Error('[contractCall] methodCall invalid structure');
    }
    const matchingMethods = utils_1.extractMethodsAndEventsFromABI(abi).filter(x => x.name === methodName);
    if (matchingMethods.length > 1) {
        throw new Error('[contractCall] function overloading is not supported in the current version');
    }
    if (!matchingMethods.length) {
        throw new Error('[contractCall] method specified does not exist in the ABI file provided');
    }
    const web3 = new web3_1.default(new web3_1.default.providers.HttpProvider(url));
    let address = null;
    if (privateKeyOrKnownAddress) {
        const networkId = await web3.eth.net.getId();
        const privateKey = config_1.getPrivateKey(privateKeyOrKnownAddress, String(networkId));
        const account = web3.eth.accounts.wallet.add(privateKey);
        address = account.address;
    }
    const networkId = await web3.eth.net.getId();
    const contractAddress = config_1.getAddress(name, String(networkId));
    // `contract` is being used as part of the eval call
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    const contract = new web3.eth.Contract(abi, contractAddress);
    // eslint-disable-next-line no-eval
    const methodObject = eval(`contract.methods.${methodCall}`);
    if (address) {
        let txParams = { from: address };
        if (extraParams) {
            txParams = Object.assign(Object.assign({}, txParams), extraParams);
        }
        const gas = await methodObject.estimateGas(txParams);
        return new Promise(resolve => {
            methodObject.send(Object.assign({ gas }, txParams)).once('transactionHash', resolve);
        });
    }
    else {
        return methodObject.call();
    }
}
exports.contractCall = contractCall;
