"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const web3_1 = tslib_1.__importDefault(require("web3"));
const utils_1 = require("./utils");
function decodeTxData(functionSignature, txData) {
    const paramsRegex = /^[^(].*\((.*)\)$/;
    if (!paramsRegex.test(functionSignature)) {
        throw new Error('Invalid function signature');
    }
    const paramsMatch = functionSignature.match(paramsRegex);
    if (!paramsMatch || !paramsMatch[1]) {
        return [];
    }
    const web3 = new web3_1.default(new web3_1.default.providers.HttpProvider(''));
    const abi = web3.eth.abi;
    const encodedFunctionSignature = abi.encodeFunctionSignature(functionSignature);
    txData = utils_1.add0x(txData);
    const txDataRegex = new RegExp('^' + encodedFunctionSignature);
    if (!txDataRegex.test(txData)) {
        throw new Error('Function signature does not match the given transaction data');
    }
    const paramsStr = paramsMatch[1];
    const params = paramsStr.split(',');
    const args = abi.decodeParameters(params, utils_1.add0x(txData.slice(10)));
    // args returns a 'EthAbiDecodeParametersResultArray', which is not exactly an array, so we have to do this
    const result = [];
    for (let i = 0; i < Object.keys(args).length; i++) {
        if (!args[i])
            continue;
        const value = utils_1.isBN(args[i]) ? args[i].toString() : args[i];
        result.push(value);
    }
    return result;
}
exports.decodeTxData = decodeTxData;
