"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs = tslib_1.__importStar(require("fs"));
const web3_1 = tslib_1.__importDefault(require("web3"));
const config_1 = require("./config");
const utils_1 = require("./utils");
async function deploy(url, privateKeyOrKnownAddress, abi, binPath, constructorArguments) {
    const web3 = new web3_1.default(new web3_1.default.providers.HttpProvider(url));
    const networkId = await web3.eth.net.getId();
    const privateKey = config_1.getPrivateKey(privateKeyOrKnownAddress, String(networkId));
    const { address } = web3.eth.accounts.wallet.add(privateKey);
    const data = utils_1.add0x(fs.readFileSync(binPath).toString());
    const Contract = web3.eth.Contract; // ts hack: transactionConfirmationBlocks is not a valid option
    const contract = new Contract(abi);
    const deploy = contract.deploy({ data, arguments: constructorArguments });
    const gas = await deploy.estimateGas({
        from: address,
    });
    return new Promise((resolve, reject) => {
        deploy.send({
            from: address,
            gas,
        }, (err, txHash) => {
            if (err) {
                return reject(err);
            }
            return resolve(txHash);
        });
    });
}
exports.deploy = deploy;
