"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const os = tslib_1.__importStar(require("os"));
const path = tslib_1.__importStar(require("path"));
const repl = tslib_1.__importStar(require("repl"));
const repl_history_1 = tslib_1.__importDefault(require("repl.history"));
const vm = tslib_1.__importStar(require("vm"));
const web3_1 = tslib_1.__importDefault(require("web3"));
const utils_1 = require("./utils");
const historyFile = path.join(os.homedir(), '.eth_cli_history');
function isRecoverableError(error) {
    if (error.name === 'SyntaxError') {
        return /^(Unexpected end of input|Unexpected token)/.test(error.message);
    }
    return false;
}
function replStarter(context, prompt) {
    const r = repl.start({
        prompt,
        eval: (cmd, context, _, callback) => {
            try {
                const result = vm.runInContext(cmd, context, {
                    displayErrors: false,
                });
                if (result && result.then) {
                    result
                        .then((x) => {
                        if (x && utils_1.isBN(x)) {
                            callback(null, x.toString());
                            return;
                        }
                        callback(null, x);
                    })
                        .catch((e) => callback(e, null));
                }
                else if (result && utils_1.isBN(result)) {
                    callback(null, result.toString());
                }
                else {
                    callback(null, result);
                }
            }
            catch (e) {
                if (isRecoverableError(e)) {
                    return callback(new repl.Recoverable(e), null);
                }
                callback(e, null);
            }
        },
    });
    r.context.Web3 = web3_1.default;
    for (const expose of Object.keys(context)) {
        r.context[expose] = context[expose];
    }
    repl_history_1.default(r, historyFile);
    return r;
}
exports.replStarter = replStarter;
