"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const web3_1 = tslib_1.__importDefault(require("web3"));
const config_1 = require("./config");
async function sendRawTransaction(url, privateKeyOrKnownAddress, to, _a) {
    var { gas } = _a, extraParams = tslib_1.__rest(_a, ["gas"]);
    const web3 = new web3_1.default(new web3_1.default.providers.HttpProvider(url));
    const networkId = await web3.eth.net.getId();
    const privateKey = config_1.getPrivateKey(privateKeyOrKnownAddress, String(networkId));
    const { address } = web3.eth.accounts.wallet.add(privateKey);
    const recipient = config_1.getAddress(to, String(networkId));
    const tx = Object.assign({ from: address, to: recipient }, extraParams);
    if (gas) {
        tx.gas = gas;
    }
    else {
        const estimatedGas = await web3.eth.estimateGas(tx);
        tx.gas = estimatedGas;
    }
    return new Promise((resolve, reject) => {
        web3.eth.sendTransaction(tx, (err, txHash) => {
            if (err) {
                return reject(err);
            }
            return resolve(txHash);
        });
    });
}
exports.sendRawTransaction = sendRawTransaction;
