"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const web3_1 = tslib_1.__importDefault(require("web3"));
const config_1 = require("./config");
async function sendTransaction(data, contractAddress, privateKeyOrKnownAddress, url) {
    const web3 = new web3_1.default(new web3_1.default.providers.HttpProvider(url));
    const networkId = await web3.eth.net.getId();
    const privateKey = config_1.getPrivateKey(privateKeyOrKnownAddress, String(networkId));
    contractAddress = config_1.getAddress(contractAddress, String(networkId));
    const { address } = web3.eth.accounts.wallet.add(privateKey);
    const tx = { from: address, data, to: contractAddress };
    const gas = await web3.eth.estimateGas(tx);
    return new Promise((resolve, reject) => {
        tx.gas = gas;
        web3.eth.sendTransaction(tx, (err, txHash) => {
            if (err) {
                return reject(err);
            }
            return resolve(txHash);
        });
    });
}
exports.sendTransaction = sendTransaction;
