"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const web3_1 = tslib_1.__importDefault(require("web3"));
const config_1 = require("./config");
const replStarter_1 = require("./replStarter");
const utils_1 = require("./utils");
async function startRepl(url, prompt, contracts, privateKeyOrKnownAddress) {
    if (!url) {
        throw new Error('[startRepl] URL require');
    }
    // Connect web3
    const web3 = new web3_1.default(new web3_1.default.providers.HttpProvider(url));
    const networkId = await web3.eth.net.getId();
    // Default context
    const replContext = {
        web3,
        eth: web3.eth,
    };
    const accounts = await web3.eth.getAccounts();
    if (privateKeyOrKnownAddress) {
        const privateKey = config_1.getPrivateKey(privateKeyOrKnownAddress, String(networkId));
        const account = web3.eth.accounts.wallet.add(privateKey);
        if (!accounts.includes(account.address)) {
            accounts.push(account.address);
        }
    }
    replContext.accounts = accounts;
    const loadedContracts = {};
    const addContract = (abiPath, address, replContext) => {
        const { abi, name } = utils_1.loadABI(abiPath);
        const transactionConfirmationBlocks = 3;
        const options = {
            transactionConfirmationBlocks,
        };
        const Contract = web3.eth.Contract; // ts hack: transactionConfirmationBlocks is not a valid option
        const contractInstance = new Contract(abi, address, options);
        let contractName = name;
        if (replContext[contractName]) {
            const suffix = Object.keys(replContext).filter(function (key) {
                return key.includes(contractName);
            }).length;
            contractName = [contractName, '_', suffix].join('');
        }
        replContext[contractName] = contractInstance;
        loadedContracts[contractName] = address;
    };
    // Add contracts into context
    for (const contract of contracts) {
        addContract(contract.abiPath, config_1.getAddress(contract.address, String(networkId)), replContext);
    }
    // Start REPL
    const r = replStarter_1.replStarter(replContext, prompt);
    r.defineCommand('contracts', {
        help: 'Show loaded contracts',
        action() {
            this.clearBufferedCommand();
            for (const [loadedContract, address] of Object.entries(loadedContracts)) {
                console.log(`${loadedContract} (${address})`);
            }
            this.displayPrompt();
        },
    });
    r.defineCommand('loadc', {
        help: 'Load a contract using the specified ABI and address',
        action(abiAndAddress) {
            this.clearBufferedCommand();
            const [abiPath, address] = abiAndAddress.split('@');
            addContract(abiPath, address, r.context);
            this.displayPrompt();
        },
    });
}
exports.startRepl = startRepl;
