"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const ora_1 = tslib_1.__importDefault(require("ora"));
const web3_1 = tslib_1.__importDefault(require("web3"));
const utils_1 = require("./utils");
exports.awaitTransactionMined = async (networkUrl, txHash, confirmationBlocks) => {
    const web3 = new web3_1.default(new web3_1.default.providers.HttpProvider(networkUrl));
    const spinner = ora_1.default('Waiting for transaction to be mined').start();
    // wait until mined
    let receipt = null;
    while (true) {
        receipt = await web3.eth.getTransactionReceipt(txHash);
        if (receipt) {
            break;
        }
        await utils_1.sleep(1000);
    }
    // wait until the specified number of blocks has passed
    while (true) {
        const blockNumber = await web3.eth.getBlockNumber();
        const blocksSinceMined = blockNumber - receipt.blockNumber;
        if (blocksSinceMined >= 0) {
            spinner.text = `${blocksSinceMined}/${confirmationBlocks} confirmations`;
            if (blocksSinceMined >= confirmationBlocks) {
                break;
            }
        }
        await utils_1.sleep(1000);
    }
    spinner.stop();
    return receipt;
};
